==> jc-1.4.0.tar.gz: soot/util/dot/DotGraphAttribute.h <==
// public class soot.util.dot.DotGraphAttribute

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 28f908b461b109d0 soot_util_dot_DotGraphAttribute

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_dot_DotGraphAttribute_H_
#define _JC_soot_util_dot_DotGraphAttribute_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_util_dot_DotGraphAttribute$sub_refs	_jc_soot_util_dot_DotGraphAttribute$sub_refs;
typedef struct _jc_soot_util_dot_DotGraphAttribute$sub_nonrefs	_jc_soot_util_dot_DotGraphAttribute$sub_nonrefs;
typedef struct _jc_soot_util_dot_DotGraphAttribute$refs	_jc_soot_util_dot_DotGraphAttribute$refs;
typedef struct _jc_soot_util_dot_DotGraphAttribute$nonrefs	_jc_soot_util_dot_DotGraphAttribute$nonrefs;
typedef struct _jc_soot_util_dot_DotGraphAttribute$object	_jc_soot_util_dot_DotGraphAttribute$object;

typedef const struct _jc_soot_util_dot_DotGraphAttribute$vmethods	_jc_soot_util_dot_DotGraphAttribute$vmethods;
typedef const struct _jc_soot_util_dot_DotGraphAttribute$vtable	_jc_soot_util_dot_DotGraphAttribute$vtable;
typedef const struct _jc_soot_util_dot_DotGraphAttribute$vtype	_jc_soot_util_dot_DotGraphAttribute$vtype;

// Constructors
extern void _jc_soot_util_dot_DotGraphAttribute$method$_init$a34354cd9552963f(_jc_env *, struct _jc_soot_util_dot_DotGraphAttribute$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_util_dot_DotGraphAttribute$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_util_dot_DotGraphAttribute$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_util_dot_DotGraphAttribute$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_util_dot_DotGraphAttribute$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_util_dot_DotGraphAttribute$object *);
};

// Vtable
struct _jc_soot_util_dot_DotGraphAttribute$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_dot_DotGraphAttribute$vmethods	soot_util_dot_DotGraphAttribute;
};

// Vtype
struct _jc_soot_util_dot_DotGraphAttribute$vtype {
	_jc_type			type;
	_jc_soot_util_dot_DotGraphAttribute$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_dot_DotGraphAttribute$sub_refs {
	struct _jc_java_lang_String$object	*id;
	struct _jc_java_lang_String$object	*value;
};

// Reference instance fields (object)
struct _jc_soot_util_dot_DotGraphAttribute$refs {
    _jc_soot_util_dot_DotGraphAttribute$sub_refs	soot_util_dot_DotGraphAttribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_dot_DotGraphAttribute$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_dot_DotGraphAttribute$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_dot_DotGraphAttribute$sub_nonrefs	soot_util_dot_DotGraphAttribute;
};

// Object instance structure
struct _jc_soot_util_dot_DotGraphAttribute$object {
	_jc_soot_util_dot_DotGraphAttribute$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_dot_DotGraphAttribute$vtype	*vtype;
	_jc_soot_util_dot_DotGraphAttribute$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_dot_DotGraphAttribute$vtype _jc_soot_util_dot_DotGraphAttribute$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_dot_DotGraphAttribute, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_dot_DotGraphAttribute$class_object;

#endif	/* _JC_soot_util_dot_DotGraphAttribute_H_ */

==> jc-1.4.6.tar.gz: soot/util/dot/DotGraphAttribute.h <==
// public class soot.util.dot.DotGraphAttribute

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 28f908b461b109d0 soot_util_dot_DotGraphAttribute

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_dot_DotGraphAttribute_H_
#define _JC_soot_util_dot_DotGraphAttribute_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_util_dot_DotGraphAttribute$sub_refs	_jc_soot_util_dot_DotGraphAttribute$sub_refs;
typedef struct _jc_soot_util_dot_DotGraphAttribute$sub_nonrefs	_jc_soot_util_dot_DotGraphAttribute$sub_nonrefs;
typedef struct _jc_soot_util_dot_DotGraphAttribute$refs	_jc_soot_util_dot_DotGraphAttribute$refs;
typedef struct _jc_soot_util_dot_DotGraphAttribute$nonrefs	_jc_soot_util_dot_DotGraphAttribute$nonrefs;
typedef struct _jc_soot_util_dot_DotGraphAttribute$object	_jc_soot_util_dot_DotGraphAttribute$object;

typedef const struct _jc_soot_util_dot_DotGraphAttribute$vmethods	_jc_soot_util_dot_DotGraphAttribute$vmethods;
typedef const struct _jc_soot_util_dot_DotGraphAttribute$vtable	_jc_soot_util_dot_DotGraphAttribute$vtable;
typedef const struct _jc_soot_util_dot_DotGraphAttribute$vtype	_jc_soot_util_dot_DotGraphAttribute$vtype;

// Constructors
extern void _jc_soot_util_dot_DotGraphAttribute$method$_init$a34354cd9552963f(_jc_env *, struct _jc_soot_util_dot_DotGraphAttribute$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_util_dot_DotGraphAttribute$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_util_dot_DotGraphAttribute$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_dot_DotGraphAttribute$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_util_dot_DotGraphAttribute$vmethods {
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_util_dot_DotGraphAttribute$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_dot_DotGraphAttribute$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_dot_DotGraphAttribute$vmethods	soot_util_dot_DotGraphAttribute;
};

// Vtype
struct _jc_soot_util_dot_DotGraphAttribute$vtype {
	_jc_type			type;
	_jc_soot_util_dot_DotGraphAttribute$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_dot_DotGraphAttribute$sub_refs {
	struct _jc_java_lang_String$object	*id;
	struct _jc_java_lang_String$object	*value;
};

// Reference instance fields (object)
struct _jc_soot_util_dot_DotGraphAttribute$refs {
    _jc_soot_util_dot_DotGraphAttribute$sub_refs	soot_util_dot_DotGraphAttribute;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_dot_DotGraphAttribute$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_dot_DotGraphAttribute$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_dot_DotGraphAttribute$sub_nonrefs	soot_util_dot_DotGraphAttribute;
};

// Object instance structure
struct _jc_soot_util_dot_DotGraphAttribute$object {
	_jc_soot_util_dot_DotGraphAttribute$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_dot_DotGraphAttribute$vtype	*vtype;
	_jc_soot_util_dot_DotGraphAttribute$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_dot_DotGraphAttribute$vtype _jc_soot_util_dot_DotGraphAttribute$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_dot_DotGraphAttribute, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_dot_DotGraphAttribute$class_object;

#endif	/* _JC_soot_util_dot_DotGraphAttribute_H_ */
